



--==============================
--		FRAMES
--============================== 
local QuestsFrame = CreateFrame("Frame", nil, ObjectiveTrackerBlocksFrame);            -- Drag Handle Frame for Maximized Objective Window ie. Shows Quests
local ObjectivesFrame = CreateFrame("Frame", nil, ObjectiveTrackerFrame.HeaderMenu);   -- Drag Handle Frame for Minimized Objective Window


--==============================
--		EVENTS
--==============================
QuestsFrame:RegisterEvent("PLAYER_ENTERING_WORLD");         --Watch Event PLAYER_ENTERING_WORLD
ObjectivesFrame:RegisterEvent("PLAYER_ENTERING_WORLD");     --Watch Event PLAYER_ENTERING_WORLD




--==============================
--		FUNCTIONS
--==============================
 local function ShowTooltip(self)
    GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT ");
	GameTooltip:AddLine("Drag me!", 1, 1, 1, 1, 1, 1);
	
	--Add Icon for moving tooltip
	--local MoveIcon = GameTooltip:CreateTexture(nil, "BACKGROUND")
	--MoveIcon:SetTexture("Interface\\Addons\\QuestMover\\Images\\MoveIcon")
	--MoveIcon:SetPoint("TOPLEFT", 530 , -20)
	--MoveIcon:SetWidth(20)
	--MoveIcon:SetHeight(20)
		
    GameTooltip:Show(); -- Shows Tooltip
  end
  
  local function HideTooltip(self)
    GameTooltip:Hide(); -- Hides Tooltip
  end  

  local function OnDragStart(self)
    self:GetParent():GetParent():StartMoving();  --Start Dragging frame
  end

  local function OnDragStop(self)
    self:GetParent():GetParent():StopMovingOrSizing(); --Stop Dragging frame
  end

  local function CheckQuestVisibility(self)
	-- Check if out Objective Tracker Frame is Minimized or Maximized based on visible Frames
	if ObjectiveTrackerBlocksFrame.QuestHeader:IsVisible() or ObjectiveTrackerBlocksFrame.ScenarioHeader:IsVisible()then
		self:Show();
		ObjectivesFrame:Hide(); -- Hide frame because Window was Maximized
    else
        self:Hide();
		ObjectivesFrame:Show(); -- Show frame because Window was Minimized
    end
  end

  ObjectiveTrackerFrame:SetClampedToScreen(true); 			-- Do not move frame off screen to get lost
  ObjectiveTrackerFrame:SetMovable(true); 					-- Allow frame to move
  ObjectiveTrackerFrame:SetUserPlaced(true); 				-- Allow user to place where frame sits on screen
  ObjectiveTrackerFrame.ignoreFramePositionManager = true;  -- Still used???
  ObjectiveTrackerFrame:SetHeight(450); 					-- Set height of our frame
  
--==============================
--		QUESTS FRAME
--==============================

  QuestsFrame:EnableMouse(true); 					-- Frame works with mouse
  QuestsFrame:SetClampedToScreen(true);    			-- Frame cannot move past screen boundries
  QuestsFrame:SetMovable(true); 					-- Frame can move
  QuestsFrame:SetUserPlaced(true); 					-- Frame is moved by user
  QuestsFrame.ignoreFramePositionManager = true; 	-- Frame is not placed by position manager
  QuestsFrame:RegisterForDrag("LeftButton");        -- Frame can be dragged and dropped
  QuestsFrame:SetPoint("TOPRIGHT",0,0);
  QuestsFrame:SetSize(250,30); 
  QuestsFrame:SetScript("OnDragStart", OnDragStart);
  QuestsFrame:SetScript("OnDragStop", OnDragStop);
  QuestsFrame:SetScript("OnEnter", ShowTooltip);
  QuestsFrame:SetScript("OnLeave", HideTooltip);
  QuestsFrame:SetScript("OnEvent",CheckQuestVisibility);
  CheckQuestVisibility(QuestsFrame);
  CheckQuestVisibility(ObjectivesFrame);

--==============================
--		OBJECTIVES FRAME
--==============================

  ObjectivesFrame:EnableMouse(true);								-- Frame works with mouse
  ObjectivesFrame:SetClampedToScreen(true);  						-- Frame cannot move past screen boundries 
  ObjectivesFrame:SetMovable(true);									-- Frame can move
  ObjectivesFrame:SetUserPlaced(true);								-- Frame is moved by user
  ObjectivesFrame.ignoreFramePositionManager = true;				-- Frame is not placed by position manager
  ObjectivesFrame:RegisterForDrag("LeftButton");					-- Frame can be dragged and dropped
  ObjectivesFrame:SetPoint("TOPRIGHT",0,0);
  ObjectivesFrame:SetSize(85,30);
  ObjectivesFrame:SetScript("OnDragStart", OnDragStart);
  ObjectivesFrame:SetScript("OnDragStop", OnDragStop);
  ObjectivesFrame:SetScript("OnEnter", ShowTooltip);
  ObjectivesFrame:SetScript("OnLeave", HideTooltip);
  ObjectivesFrame:SetScript("OnEvent",CheckQuestVisibility);
  CheckQuestVisibility(QuestsFrame);
  CheckQuestVisibility(ObjectivesFrame);

  
--==============================
--		SCRIPT HOOKS
--==============================

  ObjectiveTrackerBlocksFrame.QuestHeader:HookScript("OnShow", function() CheckQuestVisibility(QuestsFrame) end);
  ObjectiveTrackerBlocksFrame.QuestHeader:HookScript("OnHide", function() CheckQuestVisibility(QuestsFrame) end);
  ObjectiveTrackerBlocksFrame.ScenarioHeader:HookScript("OnShow", function() CheckQuestVisibility(QuestsFrame) end);
  ObjectiveTrackerBlocksFrame.ScenarioHeader:HookScript("OnHide", function() CheckQuestVisibility(QuestsFrame) end);  
  ObjectiveTrackerFrame.HeaderMenu:HookScript("OnShow", function() CheckQuestVisibility(ObjectivesFrame) end);
  ObjectiveTrackerFrame.HeaderMenu:HookScript("OnHide", function() CheckQuestVisibility(ObjectivesFrame) end);
